@@ -1,5 +1,13 @@
 from NeuroLocoMiddleware.SoftRealtimeLoop import SoftRealtimeLoop
-from TMotorCANControl.TMotorManager import TMotorManager
+
+from TMotorCANControl.CAN_Manager import MIT_Params, MIT_motor_state
+try:
+     from TMotorCANControl.TMotorManager import TMotorManager
+except ModuleNotFoundError:
+    from sys import path
+    path.append("/home/pi/TMotorCANControl/src")
+    from TMotorCANControl.TMotorManager import TMotorManager
+
 import numpy as np
 import time
 from NeuroLocoMiddleware.SysID import Chirp
