@@ -1,8 +1,15 @@
-from SoftRealtimeLoop import SoftRealtimeLoop
-from TMotorCANControl.TMotorManager import TMotorManager
+from NeuroLocoMiddleware.SoftRealtimeLoop import SoftRealtimeLoop
+
+# try to import the default version, if that fails import from local directory
+try:
+     from TMotorCANControl.TMotorManager import TMotorManager
+except ModuleNotFoundError:
+    from sys import path
+    path.append("/home/pi/TMotorCANControl/src")
+    from TMotorCANControl.TMotorManager import TMotorManager
 import numpy as np
 import time
-from SysID import Chirp
+from NeuroLocoMiddleware.SysID import Chirp
 
 with TMotorManager(motor_type='AK80-9', motor_ID=3, CSV_file="log.csv") as dev:
     dev.zero_position() # has a delay!
